;
;
; =============================================================================
;
;   DEMO9S08EL32 Demo Program
;                                 
;   Version:            1.0   Created 12/08/06
;   Author:             Spencer Ruggles , Axiom Mfg.
;   Compiler:           CodeWarrior for HCS08, SE
;       
;   Platform:           DEMO9S08EL32, AXM-0410
;   Purpose:            Demonstration Program
; =============================================================================
;
; Demonstration program for DEMO9S08EL32 board. 

;*******************************************************************
;* This stationery serves as the framework for a user application. *
;* For a more comprehensive program that demonstrates the more     *
;* advanced functionality of this processor, please see the        *
;* demonstration applications, located in the examples             *
;* subdirectory of the "Freescale CodeWarrior for HC08" program    *
;* directory.                                                      *
;*******************************************************************

; Include derivative-specific definitions
            INCLUDE 'derivative.inc'

; export symbols
            XDEF _Startup, main
            ; we export both '_Startup' and 'main' as symbols. Either can
            ; be referenced in the linker .prm file or from C/C++ later on

            XREF __SEG_END_SSTACK   ; symbol defined by the linker for the end of the stack


; variable/data section
MY_ZEROPAGE: SECTION  SHORT         ; Insert here your data definition

;RAM:          equ $80                  ; start of RAM
STACK:        equ $480                 ; top of RAM + 1
;FLASH:        equ $8000                ; start of FLASH
                               
BDH:          equ $00                  ; SCI Baud Rate High value
BDL:          equ $36                  ; SCI Baud Rate Low value - 9600 bps
SC1:          equ $00                  ; SCI CR1 value
SC2:          equ $0C                  ; SCI CR2 value, 8,1,N
SC3:          equ $00                  ; SCI CR3 value

CH0SU:        equ $20                  ; congif for cont conv, ch0
CH1SU:        equ $21                  ; config for cont conv, ch1

TLO:          equ $1F                  ; lower trigger value
THI:          equ $E0                  ; upper trigger value
                               
MODH:         equ $3F                  ; Modulo Hi count
MODL:         equ $FF                  ; Modulo Lo count
VH:           equ $00                  ; TPM Hi compare value
VL:           equ $00                  ; TPM Lo Compare Value

PTAACK:       equ $04                  ; Ack PTA Interrupt
PTAIF:        equ $08                  ; PTA Int Flag
                        
EOT:          equ $04                  ; end of text char
RDRF:         equ $20                  ; Rx Data Ready Flag


; code section
MyCode:     SECTION
main:
_Startup:
         sei                           ; mask interrupts
         ldhx   #__SEG_END_SSTACK      ; initialize the stack pointer
         txs
            
         ldhx #SOPT1                   ; H:X points to SOPT1
         clra		                
         sta ,X                        ; disable COP 

         mov #$03,PTCD                 ; init PTC[1:0]
         mov #$03,PTCDD                ; PTC[1:0] output
	 
;**********************************************************
;
; Setup Timer/PWM Channel as Output Compare to toggle LED 1
; output toggle rate approx 250ms 
;
;**********************************************************	
         mov #MODH,TPM1MODH            ; load hi modulo count
         mov #MODL,TPM1MODL            ; load lo modulo count
         mov #VH,TPM1C0VH              ; load hi compare value
         mov #VL,TPM1C0VL              ; load lo compare value
         mov #$54,TPM1C0SC             ; en CH0 int, output compare, toggle output 
         mov #$0E,TPM1SC               ; sel bus clk, prescale = 64

         lda #$08                      ; load setup value
         ldhx  #PTAPS                  ; H:X points to PTA Pin Select 
         sta ,X                        ; Configure PTA3 as interrupt input
         ldhx #PTAES                   ; H:X points to PTA Edge Select
         sta ,X                        ; PTA3 falling edge/low level detect
         ldhx #PTASC                   ; H:X points to PTA Status/Control
         lda #$02                      ; 
         sta ,X                        ; Enable PTA interrupt, Edge detect
         lda ,X                        ; get PTA Interrupt Status
         eor #PTAACK                   ; set PTAACK
         sta ,X                        ; ack existing PTA interrupt
	
         cli                           ; unmask interrupts	 
FT:
         bra FT
; ===================== Sub-Routines ==========================================

;DELAY:
;         lda #$04                     ; outer loop delay count
;         DLY2:	ldhx #$ffff            ; inner loop delay count
;         DLY1:	aix #-1                ; decrement H:X 
;         cphx #$0000                  ; update CCR
;         bne DLY1                     ; inner loop
;         	sub #$01                   ; dec acc
;         bne DLY2                     ; outer loop
;         rts                          ; return

LED1:	
         ldhx #PTCD                    ; PTC addr
         lda ,X                        ; read PTC
         eor #$01                      ; neg PTC[0]
         sta PTCD                      ; write PTC
         rts                           ; return
		
LED2:	   ldhx #PTCD                    ; PTC addr
         lda ,X                        ; read PTC
         eor #$02                      ; neg PTC[1]
         sta PTCD	                     ; write PTC
         rts                           ; return
ISR1:
         lda TPM1C0SC                  ; get CH0 status
         bclr 7,TPM1C0SC               ; clr CH0 interrupt flag
         jsr LED1                      ; toggle LED1
         rti                           ; return

ISR2:
         jsr LED2                      ; jsr LED2
         lda PTASC                     ; get PTA Status
         ldhx #PTASC                   ; get PTA Status/Control Reg addr
         eor #PTAACK
         sta ,X                        ; ack PTA Interrupt
         rti
	
; ===================== Include Files =========================================

;	include '9S08SCI.inc'                ; 9S08 SCI routines
;	include 'EL32Menu.asm'               ; menu sub-routines
	
; ===================== Constants =============================================

AXM:	
         FCB "Axiom Manufacturing"
         FCB EOT
	
EL32:
         FCB "DEMO9S08EL32"
         FCB EOT

; ======================== VECTORS ============================================

         org $FFD6	
         DC.W ISR2                     ; PTA3 ISR
	
         org $FFF4
         DC.W ISR1                     ; TPM ISR
	
;         org $FFFE
;         DC.W _Startup                 ; Program Start